@@ -68,15 +68,21 @@ static gboolean cupboard_icon_clicked(TangleButton *tanglebutton, gpointer data)
 }
 
 
-
+//This is id for handler which starts sequencer after song-view is showed.
+static gulong handler_id;
 
 static void play_sequencer (TangleActor *actor, ClutterActorBox *arg1, gpointer user_data){
+	printf("play_sequencer secuencer='%p'\n",user_data);
+	
+	printf("Disconnecting handler '%ld'\n", handler_id);
+	g_signal_handler_disconnect (actor,handler_id);
+	
 	singinggame_start_sequencer(JAMMO_SEQUENCER(user_data));
 }
 
 
-
 static void on_sequencer_stopped(JammoSequencer* sequencer_old, gpointer none) {
+	printf("Sequencer '%p' stopped\n", sequencer_old);
 	//Hide all
 	ClutterActor*	mainview = jammo_get_actor_by_id("main-views-widget"); //No drawing on stage anymore, use this.
 	clutter_container_foreach(CLUTTER_CONTAINER(mainview), tangle_actor_hide_animated, NULL);
@@ -87,6 +93,9 @@ static void on_sequencer_stopped(JammoSequencer* sequencer_old, gpointer none) {
 
 	//And show mentor again
 	tangle_actor_show(TANGLE_ACTOR(jammo_mentor_get_default()));
+	
+	//printf("Unreffing sequencer '%p'\n", sequencer_old);
+	g_object_unref(sequencer_old);
 }
 
 /*
@@ -105,7 +114,8 @@ static gboolean cupboard_song_icon_clicked(TangleButton *tanglebutton, gpointer
 
 	//Hide mentor
 	jammo_mentor_shut_up(jammo_mentor_get_default());
-	tangle_actor_hide_animated(TANGLE_ACTOR(jammo_mentor_get_default()));
+	//tangle_actor_hide_animated(TANGLE_ACTOR(jammo_mentor_get_default()));
+	clutter_actor_hide(CLUTTER_ACTOR(jammo_mentor_get_default()));
 
 	//make new sequencer and add tracks to it
 	JammoSequencer* sequencer = jammo_sequencer_new();
@@ -146,7 +156,8 @@ static gboolean cupboard_song_icon_clicked(TangleButton *tanglebutton, gpointer
 	//Hide cupboard
 	ClutterActor* old_view;
 	old_view = jammo_get_actor_by_id("cupboard-view");
-	tangle_actor_hide_animated(TANGLE_ACTOR(old_view));
+	//tangle_actor_hide_animated(TANGLE_ACTOR(old_view));
+	clutter_actor_hide(CLUTTER_ACTOR(old_view));
 
 	//Show saved song-view
 	gchar *new_name = g_strdup_printf("song-%s-view",name);
@@ -155,7 +166,9 @@ static gboolean cupboard_song_icon_clicked(TangleButton *tanglebutton, gpointer
 	clutter_actor_show(new_view);
 
 	//And start sequencer after animation is completed
-	g_signal_connect(new_view, "show-completed", G_CALLBACK(play_sequencer), sequencer );
+	//We will disconnect this handler once it has happened, so take handler_id.
+	handler_id  = g_signal_connect(new_view, "show-completed", G_CALLBACK(play_sequencer), sequencer );
+	printf("handler_id '%ld'\n",handler_id);
 	
 	return FALSE;
 }
