@@ -476,29 +476,48 @@ static void on_animation_completed(ClutterAnimation* animation, gpointer user_da
 
 static void move_others_right_if_overlapping(JammoTrackView* track_view, ClutterActor* sample_button, guint slot_index) {
 	TangleWidget* widget;
+	guint n_slots;
 	GList* children;
-	ClutterActor* actor;
+	ClutterActor* actor = NULL;
 	gfloat x;
 	ClutterAnimation* animation;
 	TangleVault* vault;
 	
 	widget = TANGLE_WIDGET(tangle_wrapper_actor_get_wrapped(TANGLE_WRAPPER_ACTOR(track_view)));
+	n_slots = (guint)(clutter_actor_get_width(sample_button) / track_view->priv->real_slot_size + 0.5);
 	for (children = tangle_widget_get_children_readonly(widget); children; children = children->next) {
 		actor = CLUTTER_ACTOR(children->data);
-		if (actor != sample_button && clutter_actor_get_x(actor) == slot_index * track_view->priv->real_slot_size) {
+		x = clutter_actor_get_x(actor);
+		if (actor != sample_button &&
+		    x < slot_index * track_view->priv->real_slot_size &&
+		    x + clutter_actor_get_width(actor) > slot_index * track_view->priv->real_slot_size) {
+			n_slots += slot_index - (guint)(x / track_view->priv->real_slot_size);
+			slot_index = (guint)(x / track_view->priv->real_slot_size);
 			break;
 		}
 		actor = NULL;
 	}
-	
+	if (!actor) {
+		for (children = tangle_widget_get_children_readonly(widget); children; children = children->next) {
+			actor = CLUTTER_ACTOR(children->data);
+			x = clutter_actor_get_x(actor);
+			if (actor != sample_button &&
+			    x >= slot_index * track_view->priv->real_slot_size &&
+			    x <= (slot_index + n_slots - 1) * track_view->priv->real_slot_size) {
+		    		n_slots -= (guint)(x / track_view->priv->real_slot_size) - slot_index;
+				break;
+			}
+			actor = NULL;
+		}
+	}
 	if (actor) {
 		for (children = tangle_widget_get_children_readonly(widget); children; children = children->next) {
 			actor = CLUTTER_ACTOR(children->data);
 			x = clutter_actor_get_x(actor);
 			if (actor != sample_button && x >= slot_index * track_view->priv->real_slot_size) {
-				x += track_view->priv->real_slot_size;
+				x += n_slots * track_view->priv->real_slot_size;
 				animation = clutter_actor_animate(actor, CLUTTER_EASE_OUT_CUBIC, 500, "x", x, NULL);
-				if (x >= track_view->priv->n_slots * track_view->priv->real_slot_size) {
+				if (x + clutter_actor_get_width(actor) > (track_view->priv->n_slots - track_view->priv->disabled_slots_end) * track_view->priv->real_slot_size) {
 					vault = tangle_vault_new(2, CLUTTER_TYPE_CONTAINER, widget, CLUTTER_TYPE_ACTOR, actor);
 					tangle_signal_connect_vault(animation, "completed", G_CALLBACK(on_animation_completed), vault);
 				} else {
@@ -509,4 +528,3 @@ static void move_others_right_if_overlapping(JammoTrackView* track_view, Clutter
 		}
 	}
 }
-
