@@ -7,6 +7,7 @@
 #include <fcntl.h> //we check some files
 #include "jammo-mentor.h"
 #include <math.h> //sin
+#include <chum/jammo-cursor.h>
 
 
 static JammoSequencer* composing_sequencer;
@@ -199,7 +200,7 @@ return sin (phasing(clutter_timeline_get_progress (clutter_alpha_get_timeline (a
 }
 
 
-static ClutterScore* score; /*This is container for animation timelines of samplebuttons*/
+static GList* animation_timelines; /*This is container for animation timelines of samplebuttons*/
 
 /*
 This function creates new jammo_sample_button from given parameters and put it to given parent ClutterActor.
@@ -222,14 +223,14 @@ static ClutterActor* create_samplebutton(gchar* themename, gchar* variation, gch
 	gulong sine_function;
 	sine_function = clutter_alpha_register_func (sine_wave, GINT_TO_POINTER(phase));
 
-	ClutterTimeline *timeline1 = tangle_timeline_new(5000+phase*20);  //each has own rhythm (use same random number than phase)
-	clutter_score_append( score, NULL, timeline1);
+	ClutterTimeline *timeline1 = tangle_timeline_new(3000+phase*20);  //each has own rhythm (use same random number than phase)
 
+	animation_timelines = g_list_append(animation_timelines,timeline1);
 	ClutterAnimation* animation;
 	animation = clutter_actor_animate_with_timeline (sample_button, 
             sine_function, 
             timeline1,
-            "opacity", 150,  //do not make it too transparency (0=transparency, 255=opaque)
+            "opacity", 200,  //do not make it too transparency (0=transparency, 255=opaque)
             "scale-y", 0.9,  //add some vertical scaling, this looks movement, but doesn't disturb movement
             NULL);
 	clutter_animation_set_loop (animation,TRUE);
@@ -275,9 +276,8 @@ static gboolean on_play_button_clicked(TangleButton* tanglebutton, gpointer sequ
 
 	if (strncmp(name,"play",4)==0)
 		{
-			//clutter_score_stop (score); //This doesn't stop timelines inside score
-			GSList *timeline;
-			for (timeline = clutter_score_list_timelines(score);timeline;timeline = timeline->next)
+			GList *timeline;
+			for (timeline = animation_timelines;timeline;timeline = timeline->next)
 				{
 				clutter_timeline_pause(CLUTTER_TIMELINE(timeline->data));
 				}
@@ -305,8 +305,11 @@ static gboolean on_play_button_clicked(TangleButton* tanglebutton, gpointer sequ
 static void on_sequencer_stopped(JammoSequencer* sequencer, gpointer play_button) {
 	printf("Sequencer stopped\n");
 	tangle_actor_show(TANGLE_ACTOR(jammo_mentor_get_default()));
-	clutter_score_start (score); //This starts all animations
-
+	GList *timeline;
+	for (timeline = animation_timelines;timeline;timeline = timeline->next)
+		{
+		clutter_timeline_start(CLUTTER_TIMELINE(timeline->data));
+		}
 	//Change button to play
 	tangle_button_set_normal_background_actor(TANGLE_BUTTON(play_button),clutter_texture_new_from_file("/opt/jammo/buttons/play-button.png", NULL));
 	tangle_button_set_interactive_background_actor(TANGLE_BUTTON(play_button),clutter_texture_new_from_file("/opt/jammo/buttons/play-button.png", NULL));
@@ -509,8 +512,6 @@ void themeselection_start_theme(const gchar* name, int variation, ClutterActor*
 	clutter_container_add(CLUTTER_CONTAINER(view), back_to_theme_selection, NULL);
 	clutter_actor_set_reactive(back_to_theme_selection,TRUE);
 	g_signal_connect (back_to_theme_selection, "button-press-event", G_CALLBACK (back_to_theme_selection_clicked),view);
-
-	score = clutter_score_new();
 	
 	int tempo_table[] = {0,140,110,90};
 	gchar* background_color_code = "some_default";
@@ -518,7 +519,8 @@ void themeselection_start_theme(const gchar* name, int variation, ClutterActor*
 	
 	int disabled_slots_for_begin = 0;
 	int disabled_slots_for_end = 0;
-	
+	float tempo_factory = 4;    //4 is default
+
 	//Advanced game sets this to TRUE
 	gboolean use_two_tracks=FALSE;
 
@@ -546,8 +548,9 @@ void themeselection_start_theme(const gchar* name, int variation, ClutterActor*
 	create_samplebutton("fantasy","110","owl.png",   "castle_110_owl_2.wav",           627.0, 158.0,TANGLE_WIDGET(view));
 	create_samplebutton("fantasy","110","wolf.png",  "castle_110_wolf_4.wav",           21.0, 204.0,TANGLE_WIDGET(view));
 	
-	background_color_code = "bbbbbbbbbbbbbbbbrrrrrrrrvvvvvvvbbbbbbbb##";
+	background_color_code = "bbbbbbbbbbbbbbbbrrrrrrrrvvvvvvvvbbbbbbbb##";
 	disabled_slots_for_end = 2;
+	tempo_factory = 3;
 	}
   else if (strncmp(name,"fantasy",7)==0 && variation==3){
 	create_samplebutton("fantasy","90", "bird.png",    "castle_90_whistle_4.wav",    611.0,  76.0,TANGLE_WIDGET(view));
@@ -558,6 +561,7 @@ void themeselection_start_theme(const gchar* name, int variation, ClutterActor*
 	create_samplebutton("fantasy","90", "unicorn.png", "castle_90_oboe_2.wav",       458.0, 101.0,TANGLE_WIDGET(view));
 	
 	background_color_code = "llllvvvvvvvvllllllllvvvvvvvvrrrrrrrrvvvv";
+	tempo_factory = 3;
 	}
 
   else if (strncmp(name,"city",4)==0 && variation==1){
@@ -579,7 +583,7 @@ void themeselection_start_theme(const gchar* name, int variation, ClutterActor*
 	create_samplebutton("city","110",  "skate.png",   "city_110_gliss_bass_2.wav",    161.0, 121.0,TANGLE_WIDGET(view));
 	create_samplebutton("city","110",  "zeppelin.png","city_110_bass_strings_2.wav",  299.0,   0.0,TANGLE_WIDGET(view));
 	
-	background_color_code = "bbbbbbbbrrrrbbbbrrrrbbbb##";
+	background_color_code = "bbbbbbbbrrrrbbbbrrrrbbbbrrrr##";
 	disabled_slots_for_end = 2;
 	}
 	else if (strncmp(name,"city",4)==0 && variation==3){
@@ -670,12 +674,19 @@ else { //advanced
 	create_samplebutton( "fantasy","advanced", "ghost_5.png",  "Fx_90_Dn_34_2_synth.wav",      648.0, 110.0,TANGLE_WIDGET(soundfamily[3]));
 
 	if (variation==1)
+		{
 		background_color_code = "rrrrrrrrbbbbbbbbrrrrrrrrbbbbbbbbrrrrrrrr"; //'rhythmic'
+		tempo_factory=5;
+		}
 	if (variation==2)
+		{
 		background_color_code = "bbbbvvvvbbbbvvvvrrrrbbbbvvvvbbbbvvvvrrrr";  //'strings'
+		tempo_factory=4;   //This is not correct. FIXME. It is not 3,4,5,6
+		}
 	if (variation==3)
 		{
 		background_color_code = "vvvvbbbbvvvvbbbbvvvvbbbbllllvvvvvvvv####";  //'synth'
+		tempo_factory=3;
 		disabled_slots_for_end = 4;
 		}
 	}
@@ -710,11 +721,20 @@ else { //advanced
 	create_samplebutton( "animal","advanced", "bird_5.png",  "Fx_110__54_4_rainstick.wav",     618.0, 110.0,TANGLE_WIDGET(soundfamily[3]));
 
 	if (variation==1)
+		{
 		background_color_code = "ggggyyyyvvvvyyyygggggggg##"; //'drumming/percussion'
+		tempo_factory=6;
+		}
 	if (variation==2)
+		{
 		background_color_code = "rrrrrrrroooooooorrrrrrrr##";  //'flute'
+		tempo_factory=5;
+		}
 	if (variation==3)
+		{
 		background_color_code = "yyyyggggyyyyggggyyyygggg##";  //'marimba'
+		tempo_factory=4;
+		}
 		
 	disabled_slots_for_end = 2; //each variations has same
 	}
@@ -750,11 +770,20 @@ else { //advanced
 	create_samplebutton( "city","advanced", "chopper_5.png",  "Fx_140_G_44_2_trumpet.wav",    638.0, 110.0,TANGLE_WIDGET(soundfamily[3]));
 
 	if (variation==1)
+		{
 		background_color_code = "yyyyrrrryyyyyyyyrrrrrrrryyyyyyyyrrrrrrrr##"; //'drums'
+		tempo_factory=4;
+		}
 	if (variation==2)
+		{
 		background_color_code = "rrrrrrrrooooyyyyyyyyrrrrrrrryyyyyyyyoooo##";  //'guitar'
+		tempo_factory=3;
+		}
 	if (variation==3)
+		{
 		background_color_code = "rrrroooorrrroooorrrroooorrrroooorrrroooo##";  //'synth'
+		tempo_factory=2.5; //This is just guess. FIXME. This is also only reason why tempo_factory is not integer.
+		}
 		
 	disabled_slots_for_end = 2; //each variations has same
 	}
@@ -797,11 +826,13 @@ if (use_two_tracks) y_offset=80;
 	clutter_actor_set_size(container_for_backingtrack_blocks,number_of_slots*WIDTH_OF_SLOT, 40.0);
 	clutter_actor_set_size(container_for_tracks,number_of_slots*WIDTH_OF_SLOT, 120.0+y_offset); //track is 80 and backingtrack is 40
 	
+
+	printf("tempo_factory (time_sig): %f\n",tempo_factory);
 	
 	//Bottom track. Below of this there will be place for scrollbar.
 	JammoEditingTrack* editing_track_theme = jammo_editing_track_new();
 	jammo_sequencer_add_track(sequencer, JAMMO_TRACK(editing_track_theme));
-	ClutterActor*	track_view = jammo_track_view_new(editing_track_theme, number_of_slots, 1000000000L, WIDTH_OF_SLOT);
+	ClutterActor*	track_view = jammo_track_view_new(editing_track_theme, number_of_slots,1000000000L/tempo_table[variation]*60*tempo_factory, WIDTH_OF_SLOT);
 	g_object_set(track_view, "disabled-slots-begin", disabled_slots_for_begin, "disabled-slots-end", disabled_slots_for_end,NULL);
 	clutter_actor_set_reactive(track_view, TRUE);
 	g_object_set(track_view, "line-every-nth-slot", 2, NULL);
@@ -815,7 +846,7 @@ if (use_two_tracks) y_offset=80;
 	//Upper track.
 	JammoEditingTrack* editing_track_theme2 = jammo_editing_track_new();
 	jammo_sequencer_add_track(sequencer, JAMMO_TRACK(editing_track_theme2));
-	ClutterActor*	track_view2 = jammo_track_view_new(editing_track_theme2, number_of_slots, 1000000000L, WIDTH_OF_SLOT);
+	ClutterActor*	track_view2 = jammo_track_view_new(editing_track_theme2, number_of_slots,1000000000L/tempo_table[variation]*60*tempo_factory, WIDTH_OF_SLOT);
 	g_object_set(track_view2, "disabled-slots-begin", disabled_slots_for_begin, "disabled-slots-end", disabled_slots_for_end,NULL);
 	clutter_actor_set_reactive(track_view2, TRUE);
 	g_object_set(track_view2, "line-every-nth-slot", 2, NULL);
@@ -845,15 +876,17 @@ if (use_two_tracks) y_offset=80;
 	clutter_actor_set_name (play_button,"play");
 	
 	g_signal_connect(sequencer, "stopped", G_CALLBACK(on_sequencer_stopped), play_button);
-	/*
-	//Load-button DEBUG
-	ClutterActor *load_button;
-	load_button=clutter_texture_new_from_file("/opt/jammo/buttons/play-button.png", NULL);
-	g_object_set(load_button, "x", 80.0,  "y", 195.0, NULL);
-	clutter_container_add(CLUTTER_CONTAINER(view), load_button, NULL);
-	clutter_actor_set_reactive(load_button,TRUE);
-	g_signal_connect (load_button, "button-press-event", G_CALLBACK (themeselection_load),NULL); //only first track_view is loaded.
-	*/
+	
+	ClutterColor red = { 255, 0, 0, 128 };
+	ClutterActor* texture;
+	ClutterActor* cursor;
+	texture = clutter_rectangle_new_with_color(&red);
+	clutter_actor_set_size(texture, 10.0, 78.0);
+	cursor = jammo_cursor_new(sequencer, texture);
+	tangle_actor_set_depth_position(TANGLE_ACTOR(cursor), 1);
+	clutter_actor_set_position(cursor, 0.0, 0.0);
+	clutter_actor_set_size(cursor, number_of_slots*WIDTH_OF_SLOT, 80.0);
+	clutter_container_add_actor(CLUTTER_CONTAINER(container_for_tracks), cursor);
 }
 
 
